@@ -46,9 +46,9 @@ def validate_address(
 
 
 def error_removed_option(message: str) -> Callable:
-    """ Takes a message and returns a callback that raises NoSuchOption
+    """Takes a message and returns a callback that raises NoSuchOption
 
-    if the value is not None. The message is used as an argument to NoSuchOption. """
+    if the value is not None. The message is used as an argument to NoSuchOption."""
 
     def f(_: Any, param: Parameter, value: Any) -> None:
         if value is not None:
@@ -118,7 +118,7 @@ def setup_ctx(
         raise RuntimeError("Could not access the private key.")
     owner = private_key_to_address(private_key_string)
     # pylint: disable=E1101
-    if web3.eth.getBalance(owner) == 0:
+    if web3.eth.get_balance(owner) == 0:
         raise RuntimeError("Account with insufficient funds.")
     deployer = ContractDeployer(
         web3=web3,
@@ -166,7 +166,9 @@ def check_version_dependent_parameters(
 @common_options
 @click.option("--save-info/--no-save-info", default=True, help="Save deployment info to a file.")
 @click.option(
-    "--max-token-networks", help="The maximum number of tokens that can be registered.", type=int,
+    "--max-token-networks",
+    help="The maximum number of tokens that can be registered.",
+    type=int,
 )
 @click.option(
     "--secret-registry-from-deployment-file",
@@ -309,6 +311,11 @@ def raiden(
     callback=validate_address,
     help="Address of TokenNetworkRegistry that MS contract looks at",
 )
+@click.option(
+    "--service-registry-from-deployment-file",
+    type=click.Path(exists=True),
+    help="The deployment file from which ServiceRegistry should be reused",
+)
 @click.pass_context
 def services(
     ctx: Context,
@@ -330,7 +337,12 @@ def services(
     service_deposit_min_price: int,
     service_registration_duration: int,
     token_network_registry_address: HexAddress,
+    service_registry_from_deployment_file: Optional[str],
 ) -> None:
+    service_registry_from_deployment_path: Optional[Path] = None
+    if service_registry_from_deployment_file:
+        service_registry_from_deployment_path = Path(service_registry_from_deployment_file)
+
     setup_ctx(
         ctx=ctx,
         private_key=private_key,
@@ -354,6 +366,7 @@ def services(
         min_price=service_deposit_min_price,
         registration_duration=service_registration_duration,
         token_network_registry_address=token_network_registry_address,
+        reuse_service_registry_from_deploy_file=service_registry_from_deployment_path,
     )
     deployed_contracts = {
         contract_name: info["address"]
@@ -417,7 +430,11 @@ def token(
     deployer = ctx.obj["deployer"]
     token_supply *= 10 ** token_decimals
     deployed_token = deployer.deploy_token_contract(
-        token_supply, token_decimals, token_name, token_symbol, token_type=ctx.obj["token_type"],
+        token_supply,
+        token_decimals,
+        token_name,
+        token_symbol,
+        token_type=ctx.obj["token_type"],
     )
     print(json.dumps(deployed_token, indent=4))
     ctx.obj["deployed_contracts"].update(deployed_token)
@@ -445,10 +462,14 @@ def token(
     help="Address of token network registry",
 )
 @click.option(
-    "--channel-participant-deposit-limit", type=int, help="Address of token network registry",
+    "--channel-participant-deposit-limit",
+    type=int,
+    help="Address of token network registry",
 )
 @click.option(
-    "--token-network-deposit-limit", type=int, help="Address of token network registry",
+    "--token-network-deposit-limit",
+    type=int,
+    help="Address of token network registry",
 )
 @click.pass_context
 def register(
@@ -509,7 +530,7 @@ def _add_token_network_deploy_info(
 ) -> None:
     """ Add deploy info dict to the deploy_*.json file """
     deployment_file_path = contracts_deployed_path(
-        chain_id=ChainID(deployer.web3.eth.chainId), version=contracts_version
+        chain_id=ChainID(deployer.web3.eth.chain_id), version=contracts_version
     )
     with deployment_file_path.open() as f:
         deployed_contracts_info: DeployedContracts = json.load(f)
@@ -521,7 +542,9 @@ def _add_token_network_deploy_info(
 
 @main.command()
 @click.option(
-    "--rpc-provider", default="http://127.0.0.1:8545", help="Address of the Ethereum RPC provider",
+    "--rpc-provider",
+    default="http://127.0.0.1:8545",
+    help="Address of the Ethereum RPC provider",
 )
 @click.option(
     "--contracts-version",
