@@ -23,19 +23,23 @@ from raiden_contracts.utils.type_aliases import PrivateKey
 
 @pytest.fixture(scope="session")
 def create_account(web3: Web3, ethereum_tester: EthereumTester) -> Callable:
-    def get(privkey: Optional[str] = None) -> HexAddress:
+    def get(privkey: Optional[PrivateKey] = None) -> HexAddress:
         if not privkey:
             privkey = get_random_privkey()
         address = private_key_to_address(privkey)
 
         if not any((is_same_address(address, x) for x in ethereum_tester.get_accounts())):
             # account has not been added to ethereum_tester, yet
-            ethereum_tester.add_account(privkey)
+            ethereum_tester.add_account(privkey.hex())
 
         for faucet in web3.eth.accounts[:10]:
             try:
-                web3.eth.sendTransaction(
-                    {"from": faucet, "to": address, "value": Wei(1 * int(units["finney"]))}
+                web3.eth.send_transaction(
+                    {
+                        "from": faucet,
+                        "to": address,
+                        "value": Wei(1 * int(units["finney"])),
+                    }
                 )
                 break
             except TransactionFailed:
@@ -47,7 +51,7 @@ def create_account(web3: Web3, ethereum_tester: EthereumTester) -> Callable:
 
 @pytest.fixture(scope="session")
 def get_accounts(create_account: Callable) -> Callable:
-    def get(number: int, privkeys: Iterable = ()) -> List:
+    def get(number: int, privkeys: Iterable[PrivateKey] = ()) -> List:
         privkeys = iter(privkeys)
         return [create_account(privkey=next(privkeys, None)) for x in range(number)]
 
@@ -65,7 +69,8 @@ def create_service_account(
         deposit = service_registry.functions.currentPrice().call()
         call_and_transact(custom_token.functions.mint(deposit), {"from": account})
         call_and_transact(
-            custom_token.functions.approve(service_registry.address, deposit), {"from": account}
+            custom_token.functions.approve(service_registry.address, deposit),
+            {"from": account},
         )
         call_and_transact(service_registry.functions.deposit(deposit), {"from": account})
         assert service_registry.functions.hasValidRegistration(account).call()
@@ -120,7 +125,7 @@ def event_handler(web3: Web3) -> Callable:
 @pytest.fixture
 def txn_cost(web3: Web3, txn_gas: Callable) -> Callable:
     def get(txn_hash: str) -> int:
-        return txn_gas(txn_hash) * web3.eth.gasPrice
+        return txn_gas(txn_hash) * web3.eth.gas_price
 
     return get
 
