@@ -235,7 +235,7 @@ def test_settle_single_direct_transfer_for_closing_party(
     create_balance_proof: Callable,
     create_balance_proof_countersignature: Callable,
 ) -> None:
-    """ Test settle of a channel with one direct transfer to the participant
+    """Test settle of a channel with one direct transfer to the participant
     that called close.
     """
     (A, B) = get_accounts(2)
@@ -315,7 +315,7 @@ def test_settle_single_direct_transfer_for_counterparty(
     create_balance_proof_countersignature: Callable,
     create_close_signature_for_no_balance_proof: Callable,
 ) -> None:
-    """ Test settle of a channel with one direct transfer to the participant
+    """Test settle of a channel with one direct transfer to the participant
     that did not call close.
     """
     (A, B) = get_accounts(2)
@@ -521,13 +521,13 @@ def test_settle_wrong_state_fail(
     ).call()
     assert state == ChannelState.CLOSED
     assert settle_block_number == TEST_SETTLE_TIMEOUT_MIN + get_block(txn_hash)
-    assert web3.eth.blockNumber < settle_block_number
+    assert web3.eth.block_number < settle_block_number
 
     with pytest.raises(TransactionFailed):
         call_settle(token_network, channel_identifier, A, vals_A, B, vals_B)
 
     mine_blocks(web3, TEST_SETTLE_TIMEOUT_MIN + 1)
-    assert web3.eth.blockNumber > settle_block_number
+    assert web3.eth.block_number > settle_block_number
 
     # Channel is settled
     call_settle(token_network, channel_identifier, A, vals_A, B, vals_B)
