@@ -74,7 +74,12 @@ def test_deploy_data_has_fields_raiden(version: Optional[str], chain_id: ChainID
         reasonable_deployment_of_a_contract(deployed)
 
 
-SERVICE_CONTRACT_NAMES = ("ServiceRegistry", "MonitoringService", "OneToN", "UserDeposit")
+SERVICE_CONTRACT_NAMES = (
+    "ServiceRegistry",
+    "MonitoringService",
+    "OneToN",
+    "UserDeposit",
+)
 
 
 @pytest.mark.parametrize("version", [None])
@@ -159,7 +164,7 @@ def test_verify_nonexistent_deployment(
 
 
 def test_verify_existent_deployment(token_network_registry_contract: Contract) -> None:
-    """ Test verify_deployed_contracts_in_filesystem() with an existent deployment data
+    """Test verify_deployed_contracts_in_filesystem() with an existent deployment data
 
     but with a fake web3 that returns a wrong block number for deployment.
     """
@@ -181,7 +186,7 @@ def test_verify_existent_deployment(token_network_registry_contract: Contract) -
 def test_verify_existent_deployment_with_wrong_code(
     token_network_registry_contract: Contract,
 ) -> None:
-    """ Test verify_deployed_contracts_in_filesystem() with an existent deployment data
+    """Test verify_deployed_contracts_in_filesystem() with an existent deployment data
 
     but with a fake web3 that does not return the correct code.
     """
