@@ -16,7 +16,7 @@ def test_settle_timeout_inrange(
     web3: Web3,
     create_close_signature_for_no_balance_proof: Callable,
 ) -> None:
-    """ The TokenNetwork constructor must enforce that settle timeout is in
+    """The TokenNetwork constructor must enforce that settle timeout is in
     the valid range.
 
     Also asserts that the constants.py and the netting channel contract values
@@ -58,7 +58,15 @@ def test_settle_timeout_inrange(
     mine_blocks(web3, TEST_SETTLE_TIMEOUT_MIN + 1)
     call_and_transact(
         token_network.functions.settleChannel(
-            channel_identifier, A, 0, 0, LOCKSROOT_OF_NO_LOCKS, B, 0, 0, LOCKSROOT_OF_NO_LOCKS
+            channel_identifier,
+            A,
+            0,
+            0,
+            LOCKSROOT_OF_NO_LOCKS,
+            B,
+            0,
+            0,
+            LOCKSROOT_OF_NO_LOCKS,
         ),
         {"from": A},
     )
